@@ -481,9 +481,9 @@ void ng_color_yuv2rgb_init(void);
 void ng_writefile_init(void);
 
 /* for yuv2rgb using lookup tables (color_lut.c, color_yuv2rgb.c) */
-unsigned long   ng_lut_red[256];
-unsigned long   ng_lut_green[256];
-unsigned long   ng_lut_blue[256];
+extern unsigned long   ng_lut_red[256];
+extern unsigned long   ng_lut_green[256];
+extern unsigned long   ng_lut_blue[256];
 void ng_yuv422_to_lut2(unsigned char *dest, unsigned char *s, int p);
 void ng_yuv422_to_lut4(unsigned char *dest, unsigned char *s, int p);
 void ng_yuv420p_to_lut2(void *h, struct ng_video_buf *out,
@@ -502,10 +502,10 @@ void  ng_packed_frame(void *handle, struct ng_video_buf *out,
 void* ng_conv_nop_init(struct ng_video_fmt *out, void *priv);
 void  ng_conv_nop_fini(void *handle);
 
-#define NG_GENERIC_PACKED			\
-	init:           ng_packed_init,		\
-	frame:          ng_packed_frame,       	\
-	fini:           ng_conv_nop_fini
+#define NG_GENERIC_PACKED				\
+	.init =           ng_packed_init,		\
+	.frame =          ng_packed_frame,       	\
+	.fini =           ng_conv_nop_fini
 
 #endif /* NG_PRIVATE */
 
