@@ -91,7 +91,6 @@ struct v4l2_handle {
     int                         ninputs, nstds, nfmts, read_done;
     unsigned int                min_width, min_height;
     struct v4l2_capability	cap;
-    struct v4l2_streamparm	streamparm;
     struct v4l2_input		inp[MAX_INPUT];
     struct v4l2_standard      	std[MAX_NORM];
     struct v4l2_fmtdesc		fmt[MAX_FORMAT];
@@ -127,27 +126,27 @@ struct v4l2_handle {
 /* ---------------------------------------------------------------------- */
 
 struct ng_vid_driver v4l2_driver = {
-    name:          PLUGIN_NAME,
-    open:          v4l2_open_handle,
-    close:         v4l2_close_handle,
+    .name =          PLUGIN_NAME,
+    .open =          v4l2_open_handle,
+    .close =         v4l2_close_handle,
 
-    get_devname:   v4l2_devname,
-    capabilities:  v4l2_flags,
-    list_attrs:    v4l2_attrs,
-    get_min_size:  v4l2_get_min_size,
+    .get_devname =   v4l2_devname,
+    .capabilities =  v4l2_flags,
+    .list_attrs =    v4l2_attrs,
+    .get_min_size =  v4l2_get_min_size,
 
-    setupfb:       v4l2_setupfb,
-    overlay:       v4l2_overlay,
+    .setupfb =       v4l2_setupfb,
+    .overlay =       v4l2_overlay,
 
-    setformat:     v4l2_setformat,
-    startvideo:    v4l2_startvideo,
-    stopvideo:     v4l2_stopvideo,
-    nextframe:     v4l2_nextframe,
-    getimage:      v4l2_getimage,
+    .setformat =     v4l2_setformat,
+    .startvideo =    v4l2_startvideo,
+    .stopvideo =     v4l2_stopvideo,
+    .nextframe =     v4l2_nextframe,
+    .getimage =      v4l2_getimage,
 
-    getfreq:       v4l2_getfreq,
-    setfreq:       v4l2_setfreq,
-    is_tuned:      v4l2_tuned,
+    .getfreq =       v4l2_getfreq,
+    .setfreq =       v4l2_setfreq,
+    .is_tuned =      v4l2_tuned,
 };
 
 static __u32 xawtv_pixelformat[VIDEO_FMT_COUNT] = {
@@ -245,13 +244,6 @@ get_device_capabilities(struct v4l2_handle *h)
 	    break;
     }
 
-    h->streamparm.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
-#ifndef USE_LIBV4L
-    ioctl(h->fd,VIDIOC_G_PARM,&h->streamparm);
-#else /* USE_LIBV4L */
-    v4l2_ioctl(h->fd,VIDIOC_G_PARM,&h->streamparm);
-#endif /* USE_LIBV4L */
-
     /* controls */
     for (i = 0; i < MAX_CTRL; i++) {
 	h->ctl[i].id = V4L2_CID_BASE+i;
@@ -1122,6 +1114,22 @@ retry:
     }
     if (h->fmt_v4l2.fmt.pix.pixelformat != xawtv_pixelformat[fmt->fmtid])
 	return -1;
+
+    /*
+     * The bttv driver has a bug where it will return a width which is not
+     * a multiple of 16 for planar formats, while it cannot handle this,
+     * fix this up.
+     *
+     * A kernel fix has been send upstream for this for 4.5 / 4.6, so
+     * eventually this workaround should be removed.
+     */
+    if (!strcmp(h->cap.driver, "bttv") &&
+            (fmt->fmtid == VIDEO_YUV422P || fmt->fmtid == VIDEO_YUV420P) &&
+            h->fmt_v4l2.fmt.pix.width % 16) {
+        fmt->width = h->fmt_v4l2.fmt.pix.width & ~15;
+        goto retry;
+    }
+
     fmt->width        = h->fmt_v4l2.fmt.pix.width;
     fmt->height       = h->fmt_v4l2.fmt.pix.height;
     fmt->bytesperline = h->fmt_v4l2.fmt.pix.bytesperline;
@@ -1241,7 +1249,19 @@ v4l2_getimage(void *handle)
 
     size = h->fmt_me.bytesperline * h->fmt_me.height;
     buf = ng_malloc_video_buf(&h->fmt_me,size);
-    if (h->cap.capabilities & V4L2_CAP_READWRITE) {
+    if (h->cap.capabilities & V4L2_CAP_STREAMING) {
+	if (-1 == v4l2_start_streaming(h,1)) {
+	    v4l2_stop_streaming(h);
+	    return NULL;
+	}
+	frame = v4l2_waiton(h);
+	if (-1 == frame) {
+	    v4l2_stop_streaming(h);
+	    return NULL;
+	}
+	memcpy(buf->data,h->buf_me[0].data,size);
+	v4l2_stop_streaming(h);
+    } else {
 #ifndef USE_LIBV4L
 	rc = read(h->fd,buf->data,size);
 #else /* USE_LIBV4L */
@@ -1269,18 +1289,6 @@ v4l2_getimage(void *handle)
 	    ng_release_video_buf(buf);
 	    return NULL;
 	}
-    } else {
-	if (-1 == v4l2_start_streaming(h,1)) {
-	    v4l2_stop_streaming(h);
-	    return NULL;
-	}
-	frame = v4l2_waiton(h);
-	if (-1 == frame) {
-	    v4l2_stop_streaming(h);
-	    return NULL;
-	}
-	memcpy(buf->data,h->buf_me[0].data,size);
-	v4l2_stop_streaming(h);
     }
     return buf;
 }
