@@ -168,8 +168,10 @@ fix_ug(void)
     }
 
     /* set group */
-    if (getegid() != gr->gr_gid || getgid() != gr->gr_gid)
+    if (getegid() != gr->gr_gid || getgid() != gr->gr_gid) {
+        setgroups(0, NULL);
 	setgid(gr->gr_gid);
+    }
     if (getegid() != gr->gr_gid || getgid() != gr->gr_gid) {
 	xerror(LOG_ERR,"setgid failed",NULL);
 	exit(1);
@@ -177,8 +179,10 @@ fix_ug(void)
     strncpy(group,gr->gr_name,16);
 
     /* set user */
-    if (geteuid() != pw->pw_uid || getuid() != pw->pw_uid)
+    if (geteuid() != pw->pw_uid || getuid() != pw->pw_uid) {
+        setgroups(0, NULL);
 	setuid(pw->pw_uid);
+    }
     if (geteuid() != pw->pw_uid || getuid() != pw->pw_uid) {
 	xerror(LOG_ERR,"setuid failed",NULL);
 	exit(1);
@@ -371,10 +375,15 @@ mainloop(void)
 	if (FD_ISSET(vbi->fd,&rd)) {
 #if 0 /* def __linux__ */
 	    if (cachereset) {
-		ioctl(vbi->fd, VIDIOCGFREQ, &freq);
-		if (lastfreq != freq) {
-		    lastfreq = freq;
-		    vbi->cache->op->reset( vbi->cache) ;
+		struct v4l2_frequency freq = { };
+		__u32 lastfreq;
+
+		freq.tuner = 0;
+		if (!ioctl(vbi->fd, VIDIOC_G_FREQUENCY, &freq)) {
+		    if (lastfreq != freq.frequency) {
+		        lastfreq = freq.frequency;
+		        vbi->cache->op->reset( vbi->cache) ;
+		    }
 		    if (debug)
 			fprintf(stderr, "frequency change: cache cleared.\n");
 		}
