@@ -20,6 +20,7 @@
 #include <sys/ioctl.h>
 
 #include <X11/Xlib.h>
+#include <X11/XKBlib.h>
 #include <X11/Xatom.h>
 #include <X11/Intrinsic.h>
 #include <X11/keysym.h>
@@ -396,7 +397,7 @@ vbi_kbd_eh(Widget widget, XtPointer clientdata, XEvent *event, Boolean *cont)
 
     switch (event->type) {
     case KeyPress:
-	sym = XKeycodeToKeysym(XtDisplay(widget),event->xkey.keycode,0);
+	sym = XkbKeycodeToKeysym(XtDisplay(widget),event->xkey.keycode,0,0);
 	digit = -1;
 	switch (sym) {
 	case XK_0:
@@ -539,10 +540,10 @@ static void
 export_do_save_cb(Widget widget, XtPointer clientdata, XtPointer call_data)
 {
     static struct vbi_rect rect = {
-	x1:  0,
-	x2: 41,
-	y1:  0,
-	y2: 25,
+	.x1 =  0,
+	.x2 = 41,
+	.y1 =  0,
+	.y2 = 25,
     };
     XmFileSelectionBoxCallbackStruct *cb = call_data;
     struct vbi_window *vw = clientdata;
@@ -580,13 +581,13 @@ static void
 export_save_cb(Widget widget, XtPointer clientdata, XtPointer call_data)
 {
     struct vbi_window *vw = clientdata;
-    Widget help,text,menu,option,push;
+    Widget help,text=text,menu,option,push;
     Arg args[2];
 
     if (NULL == vw->savebox) {
 	vw->savebox = XmCreateFileSelectionDialog(vw->shell,"save",NULL,0);
 	help = XmFileSelectionBoxGetChild(vw->savebox,XmDIALOG_HELP_BUTTON);
-	text = XmFileSelectionBoxGetChild(vw->savebox,XmDIALOG_TEXT);
+	XmFileSelectionBoxGetChild(vw->savebox,XmDIALOG_TEXT);
 	XtUnmanageChild(help);
 
 	menu = XmCreatePulldownMenu(vw->savebox,"formatM",NULL,0);
@@ -917,10 +918,10 @@ static void vbi_station_cb(Widget widget, XtPointer client, XtPointer call)
 	struct v4l2_frequency frequency;
 
 	memset (&frequency, 0, sizeof(frequency));
-	frequency.type = V4L2_TUNER_RADIO;
+	frequency.type = V4L2_TUNER_ANALOG_TV;
 	frequency.frequency = channels[i]->freq;
 	if (-1 == ioctl(vbi->fd, VIDIOC_S_FREQUENCY, &frequency))
-	    perror("ioctl VIDIOCSFREQ");
+	    perror("ioctl VIDIOC_S_FREQUENCY");
     }
 #endif
 
